
goog.provide("node.net.Socket");

goog.require("node.buffer.Buffer");

/**
 * @constructor
 */
node.net.Socket = function() {};

/**
 * @type {node.buffer.Buffer|null}
 */
node.net.Socket.prototype.bufferSize = null;

/**
 * @type {string|null}
 */
node.net.Socket.prototype.fd = null;

/**
 * @type {string|null}
 */
node.net.Socket.prototype.type = null;

/**
 * @type {string|null}
 */
node.net.Socket.prototype.allowHalfOpen = null;

/**
 * @param {string} fd
 * @param {string} type
 */
node.net.Socket.prototype.open = function(fd, type) {
  return node.net.Socket.core_.open(fd, type);
};

/**
 * @param {string} data
 * @param {string} [fd]
 * @param {string} [cb]
 */
node.net.Socket.prototype.write = function(data, [fd], [cb]) {
  return node.net.Socket.core_.write(data, [fd], [cb]);
};

/**
 *
 */
node.net.Socket.prototype.flush = function() {
  return node.net.Socket.core_.flush();
};

/**
 * @param {string=} encoding
 */
node.net.Socket.prototype.setEncoding = function(encoding) {
  return node.net.Socket.core_.setEncoding(encoding);
};

/**
 *
 */
node.net.Socket.prototype.connect = function() {
  return node.net.Socket.core_.connect();
};

/**
 *
 */
node.net.Socket.prototype.address = function() {
  return node.net.Socket.core_.address();
};

/**
 * @param {string} v
 */
node.net.Socket.prototype.setNoDelay = function(v) {
  return node.net.Socket.core_.setNoDelay(v);
};

/**
 * @param {string} enable
 * @param {string} time
 */
node.net.Socket.prototype.setKeepAlive = function(enable, time) {
  return node.net.Socket.core_.setKeepAlive(enable, time);
};

/**
 * @param {string} msecs
 * @param {function(Error?,...[*]):undefined=} callback
 */
node.net.Socket.prototype.setTimeout = function(msecs, callback) {
  return node.net.Socket.core_.setTimeout(msecs, callback);
};

/**
 *
 */
node.net.Socket.prototype.pause = function() {
  return node.net.Socket.core_.pause();
};

/**
 *
 */
node.net.Socket.prototype.resume = function() {
  return node.net.Socket.core_.resume();
};

/**
 *
 */
node.net.Socket.prototype.destroySoon = function() {
  return node.net.Socket.core_.destroySoon();
};

/**
 * @param {string} exception
 */
node.net.Socket.prototype.destroy = function(exception) {
  return node.net.Socket.core_.destroy(exception);
};

/**
 * @param {string} data
 * @param {string=} encoding
 */
node.net.Socket.prototype.end = function(data, encoding) {
  return node.net.Socket.core_.end(data, encoding);
};

/**
 * @param {string} dest
 * @param {Object} options
 */
node.net.Socket.prototype.pipe = function(dest, options) {
  return node.net.Socket.core_.pipe(dest, options);
};

/**
 * @param {string} n
 */
node.net.Socket.prototype.setMaxListeners = function(n) {
  return node.net.Socket.core_.setMaxListeners(n);
};

/**
 * @param {string} type
 */
node.net.Socket.prototype.emit = function(type) {
  return node.net.Socket.core_.emit(type);
};

/**
 * @param {string} type
 * @param {string} listener
 */
node.net.Socket.prototype.addListener = function(type, listener) {
  return node.net.Socket.core_.addListener(type, listener);
};

/**
 * @param {string} type
 * @param {string} listener
 */
node.net.Socket.prototype.on = function(type, listener) {
  return node.net.Socket.core_.on(type, listener);
};

/**
 * @param {string} type
 * @param {string} listener
 */
node.net.Socket.prototype.once = function(type, listener) {
  return node.net.Socket.core_.once(type, listener);
};

/**
 * @param {string} type
 * @param {string} listener
 */
node.net.Socket.prototype.removeListener = function(type, listener) {
  return node.net.Socket.core_.removeListener(type, listener);
};

/**
 * @param {string} type
 */
node.net.Socket.prototype.removeAllListeners = function(type) {
  return node.net.Socket.core_.removeAllListeners(type);
};

/**
 * @param {string} type
 */
node.net.Socket.prototype.listeners = function(type) {
  return node.net.Socket.core_.listeners(type);
};


/**
 * @private
 * @type {*}
 */
node.net.Socket.core_ = require("net").Socket;